pub struct EventBodyBorrowed<'a> {
pub kind: &'a str,
pub detail1: i32,
pub detail2: i32,
pub any_data: Value<'a>,
pub(crate) properties: Properties,
}Fields
kind: &'a strkind variant, used for specifying an event triple “object:state-changed:focused”, the “focus” part of this event is what is contained within the kind.
detail1: i32Generic detail1 value described by AT-SPI.
detail2: i32Generic detail2 value described by AT-SPI.
any_data: Value<'a>Generic any_data value described by AT-SPI.
This can be any type.
properties: PropertiesNot in use.
See: Properties.
Implementations
Sourceimpl EventBodyBorrowed<'_>
impl EventBodyBorrowed<'_>
Sourcepub fn to_fully_owned(&self) -> Result<EventBodyOwned, AtspiError>
pub fn to_fully_owned(&self) -> Result<EventBodyOwned, AtspiError>
Convert this borrowed event body to an owned event body.
Errors
This will error if the following conditions are met:
- the
any_datafield contains anstd::os::fd::OwnedFdtype, and - the maximum number of open files for the process is exceeded.
Chances are slim because none of the types in crate::events use std::os::fd::OwnedFd.
See zvariant::Value::try_clone for more information.