pub struct EventBodyQtOwned {
pub kind: String,
pub detail1: i32,
pub detail2: i32,
pub any_data: OwnedValue,
pub(crate) properties: QtProperties,
}Expand description
Event body as used exclusively by ‘Qt’ toolkit.
Signature: “siiv(so)”
Fields
kind: Stringkind variant, used for specifying an event triple “object:state-changed:focused”, the “focus” part of this event is what is contained within the kind.
detail1: i32Generic detail1 value described by AT-SPI.
detail2: i32Generic detail2 value described by AT-SPI.
any_data: OwnedValueGeneric any_data value described by AT-SPI.
This can be any type.
properties: QtPropertiesNot in use.
See: QtProperties.